*********************************************************************************
/*
# Data

# The Political Economy of Life Satisfaction

- Nisha Bellinger
- Jonathan Krieckhaus
- Byunghwan Son (contact: bson3@gmu.edu)

*/
*********************************************************************************
clear

* Globals

global source "XXXXX" // just set up a folder in your computer for your source data to be stored.

/*

# two files need to be saved in the 'source' folder before proceeding.
	- the 'code.do' file: this is included in the replication package ('LifeSat_replication.zip')
	- WVS 'time series' dataset. We used 'WVS Longitudinal 1981-2016 r v20180912', but any version covering up to 2014 should work. (https://www.worldvaluessurvey.org/WVSDocumentationWVL.jsp)

*/

global data "YYYYY" // just set up a folder in your computer for your data for analysis to be stored. 


* global level
** WDI
cd"$source"
ssc install wbopendata, replace
wbopendata, indicator(NY.GDP.PCAP.KD; NY.GDP.MKTP.KD.ZG; NY.GDP.DEFL.KD.ZG; ///
						NY.GDP.MKTP.KD) 	clear long
rename ny_gdp_pcap_kd gdppc
label variable gdppc "GDP per capita"
rename ny_gdp_mktp_kd_zg growth
label variable growth "GDP growth (\%)" 
rename ny_gdp_defl_kd_zg inflation
label variable inflation "inflation"
rename ny_gdp_mktp_kd GDP 
label variable GDP "GDP"
gen lngdp = ln(GDP)
gen lngdppc = ln(gdppc)
							
gen lninfl = .
	replace lninfl = ln(1+inflation) if inflation>=0
	replace lninfl = -ln(1-inflation) if inflation<0
	
	rename countryname country

cd "$source"
run code.do

cd "$data"
sort code year
save wdi, replace

** democracy
clear

// added political terror scale (US state dept) added (3/1/2018)

use fh_cl fh_pr fh_status p_polity2 ciri_physint chga_demo year cname gd_ptss /// 
	using "http://www.qogdata.pol.gu.se/data/qog_std_cs_jan18.dta", clear

	gen fh = fh_pr + fh_cl
rename cname country

cd "$source"
run code.do
cd "$data"
sort code year
save qog, replace

** political terror scale
use Country Year COW_Code_A COW_Code_N WordBank_Code_A UN_Code_N PTS_A PTS_H PTS_S /// 
	using "http://www.politicalterrorscale.org/Data/Files/PTS-2017.dta", clear

	decode Country, gen(country)
	rename Year year
	
	cd "$source"
	run code.do
	cd "$data"
	sort code year
	save pts, replace

* individual level


cd "$source"
use WhateverNameYouUsedtoSaveWVSdata, clear


gen sat = A170
replace sat=. if A170<1
label variable sat "life satisfaction"

gen happ = A008
	replace happ=. if A008<1
	recode happ 4=0 3=1 2=2 1=3
	label variable happ "feeling happy"
	
gen health = A009
	replace health=. if A009<1
	recode health 4=0 3=1 2=2 1=3


gen income = X047
replace income=. if X047<1
label variable income "income level"

gen trust = A165
replace trust=. if trust<1
recode trust 1=1 2=0
label var trust "Interpersonal Trust"

gen ideo = E033
replace ideo=. if ideo<1

label var ideo "Left Ideology"
recode ideo 10=1 9=2 8=3 7=4 6=5 5=6 4=7 3=8 2=9 1=10

gen male = X001
replace male=. if male<1
recode male 1=1 2=0
label var male "Gender: female = 0, male=1"

gen age = X003 
replace age=. if age<1
label var age "Age"

gen edu = X025
replace edu=. if edu<1
label var edu "Education"

ssc install sdecode, replace
 sdecode S003, gen(country)

gen year=S020

keep country year S002 sat happ health income trust ideo male age edu


run "/Users/bson3/Library/CloudStorage/OneDrive-GeorgeMasonUniversity-O365Production/temp/data/code.do"

cd "$data"
sort code year
save wvs_temp, replace


* merge
clear
cd "$data"
use wvs_temp
merge code year using wdi
drop _merge
sort code year
merge code year using qog
drop _merge
sort code year
merge code year using pts
drop _merge
sort code year
cd "$source"
*merge code year using inequality
*drop _merge

cd "$data"
gen id = year*1000 + code


gen fh = fh_cl + fh_pr

sort code year
save data, replace


* end of 'data.do'
******************
